package com.shzg.project.worn.service;

import java.util.List;
import com.shzg.project.worn.domain.WornMaterialUnit;

/**
 * 物料单位Service接口
 * 
 * @author shzg
 * @date 2026-03-11
 */
public interface IWornMaterialUnitService 
{
    /**
     * 查询物料单位
     * 
     * @param id 物料单位主键
     * @return 物料单位
     */
    public WornMaterialUnit selectWornMaterialUnitById(Long id);

    /**
     * 查询物料单位列表
     * 
     * @param wornMaterialUnit 物料单位
     * @return 物料单位集合
     */
    public List<WornMaterialUnit> selectWornMaterialUnitList(WornMaterialUnit wornMaterialUnit);

    /**
     * 新增物料单位
     * 
     * @param wornMaterialUnit 物料单位
     * @return 结果
     */
    public int insertWornMaterialUnit(WornMaterialUnit wornMaterialUnit);

    /**
     * 修改物料单位
     * 
     * @param wornMaterialUnit 物料单位
     * @return 结果
     */
    public int updateWornMaterialUnit(WornMaterialUnit wornMaterialUnit);

    /**
     * 批量删除物料单位
     * 
     * @param ids 需要删除的物料单位主键集合
     * @return 结果
     */
    public int deleteWornMaterialUnitByIds(Long[] ids);

    /**
     * 删除物料单位信息
     * 
     * @param id 物料单位主键
     * @return 结果
     */
    public int deleteWornMaterialUnitById(Long id);
}
