package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.WornMaterialUnit;
import com.shzg.project.worn.service.IWornMaterialUnitService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * 物料单位Controller
 * 
 * @author shzg
 * @date 2026-03-11
 */
@RestController
@RequestMapping("/worn/unit")
public class WornMaterialUnitController extends BaseController
{
    @Autowired
    private IWornMaterialUnitService wornMaterialUnitService;

    /**
     * 查询物料单位列表
     */
    @PreAuthorize("@ss.hasPermi('worn:unit:list')")
    @GetMapping("/list")
    public TableDataInfo list(WornMaterialUnit wornMaterialUnit)
    {
        startPage();
        List<WornMaterialUnit> list = wornMaterialUnitService.selectWornMaterialUnitList(wornMaterialUnit);
        return getDataTable(list);
    }

    /**
     * 导出物料单位列表
     */
    @PreAuthorize("@ss.hasPermi('worn:unit:export')")
    @Log(title = "物料单位", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WornMaterialUnit wornMaterialUnit)
    {
        List<WornMaterialUnit> list = wornMaterialUnitService.selectWornMaterialUnitList(wornMaterialUnit);
        ExcelUtil<WornMaterialUnit> util = new ExcelUtil<WornMaterialUnit>(WornMaterialUnit.class);
        util.exportExcel(response, list, "物料单位数据");
    }

    /**
     * 获取物料单位详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:unit:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wornMaterialUnitService.selectWornMaterialUnitById(id));
    }

    /**
     * 新增物料单位
     */
    @PreAuthorize("@ss.hasPermi('worn:unit:add')")
    @Log(title = "物料单位", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WornMaterialUnit wornMaterialUnit)
    {
        return toAjax(wornMaterialUnitService.insertWornMaterialUnit(wornMaterialUnit));
    }

    /**
     * 修改物料单位
     */
    @PreAuthorize("@ss.hasPermi('worn:unit:edit')")
    @Log(title = "物料单位", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WornMaterialUnit wornMaterialUnit)
    {
        return toAjax(wornMaterialUnitService.updateWornMaterialUnit(wornMaterialUnit));
    }

    /**
     * 删除物料单位
     */
    @PreAuthorize("@ss.hasPermi('worn:unit:remove')")
    @Log(title = "物料单位", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wornMaterialUnitService.deleteWornMaterialUnitByIds(ids));
    }
}
